/* SPDX-License-Identifier: LGPL-2.1-only OR BSD-3-Clause */
/******************************************************************************
 *
 * This file is provided under a dual license.  When you use or
 * distribute this software, you may choose to be licensed under
 * version 2.1 of the GNU Lesser General Public License
 * ("LGPLv2.1 License") or BSD License.
 *
 * LGPLv2.1 License
 *
 * Copyright(C) 2019 MediaTek Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2.1 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html for more
 * details.
 *
 * BSD LICENSE
 *
 * Copyright(C) 2019 MediaTek Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/*-----------------------------------------------------------------------------
 *
 * $Author: shuo.ding $
 * $Date: 2015/08/04 $
 * $RCSfile: pmx_hw.h,v $
 * $Revision: #2 $
 *
 *---------------------------------------------------------------------------*/

/** @file pmx_hw.h
 *  Brief of file pmx_hw.h.
 *  Details of file pmx_hw.h (optional).
 */

#ifndef PMX_HW_H
#define PMX_HW_H


//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------

#include "x_lint.h"
//LINT_EXT_HEADER_BEGIN
#include "x_typedef.h"
#include "x_hal_5381.h"
//LINT_EXT_HEADER_END


//-----------------------------------------------------------------------------
// Constant definitions
//-----------------------------------------------------------------------------

#define REG_OS_ALPHA_MIX1 0x5c0
#define REG_OS_ALPHA_MIX2 0x5c4
#define REG_OS_BGCOLOR 0x5c8
#define REG_OS_BGCOLOR_MSK (0xffffff)
#define REG_OS_PATTERN 0x4a4
#define REG_OS_FASTBLANK_MSK (1 << 2)
#define REG_OS_PATTERN_MSK (1 << 3)
#define REG_NUM 2
#define PMX_PLANE_NUMBER 5

typedef enum _PMX_MIX_AL_VIDEO_T
{
    PMX_MIX_AL_VIDEO_BOT,
    PMX_MIX_AL_VIDEO_1_OSD_BELOW,
    PMX_MIX_AL_VIDEO_2_OSD_BELOW,
    PMX_MIX_AL_VIDEO_TOP,
    PMX_MIX_AL_VIDEO_MAX,
} PMX_MIX_AL_VIDEO_T;

typedef enum _PMX_OSD_MIX_AL_T
{
    OSD_MIX_AL_11,
    OSD_MIX_AL_12,
    OSD_MIX_AL_2,
    OSD_MIX_AL_MAX,
} PMX_OSD_MIX_AL_T;


//-----------------------------------------------------------------------------
// Inter-file functions
//-----------------------------------------------------------------------------

EXTERN void _PMX_Init(void);
EXTERN void _PMX_SetPlaneOrder(UCHAR ucPlaneId, UCHAR ucPlaneOrder);
EXTERN void _PMX_SetPlaneOrderArray(const UINT32 *pu4PlaneOrder);
EXTERN void _PMX_SetAlpha(UCHAR ucPlaneId, UCHAR ucValue);
EXTERN void _PMX_SetBgColor(UINT32 u4Value, BOOL fgYuvMode, BOOL fgInVsync);
#ifdef CC_FOR_POC_DEMO
EXTERN void _PMX_SetBlkColor(UINT32 u4BlkColor);
#endif
EXTERN void _PMX_Set_ALPHA_MIX_GRP1_0(BOOL fgEnable);
EXTERN void _PMX_Set_ALPHA_MIX_GRP12_0(BOOL fgEnable);

EXTERN void _PMX_Set_ALPHA_MIX_VIDEO_BOT(const UINT32 *pu4Alpha);
EXTERN void _PMX_Set_ALPHA_MIX_VIDEO_1_OSD_BELOW(const UINT32 *pu4Alpha);
EXTERN void _PMX_Set_ALPHA_MIX_VIDEO_2_OSD_BELOW(const UINT32 *pu4Alpha);
EXTERN void _PMX_Set_ALPHA_MIX_VIDEO_TOP(const UINT32 *pu4Alpha);

#endif // PMX_HW_H
